- The Martini3 structures are from the following reference: Ozturk TN, König M, Carpenter TS, Pedersen KB, Wassenaar TA, Ingólfsson HI, Marrink SJ: Building complex membranes with Martini 3. In Methods in Enzymology. Elsevier; 2024:S0076687924000946.

- These invaluable structures were generously provided by Tugba Nur Ozturk, Melanie Konig, and Helgi Ingolfur Ingolfsson, aiding in the debugging of the backmapping tool and testing compatibility with Martini3 structures generated by Martini tools.

- The resulting all-atom structures are available at the following link. Each folder has 'step4_final.pdb', which is the backmapped, all-atom structure:

https://www.dropbox.com/scl/fo/10jy9duez1joho8ans8y6/AE3UsoB9ff_DtNkBMNIO0ns?rlkey=szqblnysoihwlxmkng8t2j85u&dl=0

